@@ -174,6 +174,6 @@ plot.HCPC <- function(x, axes=c(1,2), choice="3D.map", rect=TRUE, draw.tree=TRUE
       if(draw.tree) f.draw.tree(X, merge=res$call$t$tree$merge, height=res$call$t$tree$height, dimens=2, t.level=t.level, axes=axes,...)
     }
   }
-  if(choice=="tree") par(def.par)
+  if(choice=="tree" & tree.barplot) par(def.par)
   invisible()
 }
